@@ -134,18 +134,10 @@ sub nth_twin_prime_approx {
 }
 
 
-sub is_prime {
-  my($n) = @_;
-  return 0 if defined $n && int($n) < 0;
-  _validate_positive_integer($n);
-  return Math::Prime::Util::PP::is_prime($n);
-}
-sub is_prob_prime {
-  my($n) = @_;
-  return 0 if defined $n && int($n) < 0;
-  _validate_positive_integer($n);
-  return Math::Prime::Util::PP::is_prob_prime($n);
-}
+*is_prime       = \&Math::Prime::Util::PP::is_prime;
+*is_prob_prime  = \&Math::Prime::Util::PP::is_prob_prime;
+*is_bpsw_prime  = \&Math::Prime::Util::PP::is_bpsw_prime;
+
 sub is_pseudoprime {
   my($n, $base) = @_;
   return 0 if defined $n && int($n) < 0;
@@ -186,6 +178,19 @@ sub is_almost_extra_strong_lucas_pseudoprime {
   } else                  { $increment = 1; }
   return Math::Prime::Util::PP::is_almost_extra_strong_lucas_pseudoprime($n, $increment);
 }
+sub is_perrin_pseudoprime {
+  my($n) = @_;
+  return 0 if defined $n && int($n) < 0;
+  _validate_positive_integer($n);
+  return Math::Prime::Util::PP::is_perrin_pseudoprime($n);
+}
+sub is_frobenius_pseudoprime {
+  my($n, $P, $Q) = @_;
+  return 0 if defined $n && int($n) < 0;
+  _validate_positive_integer($n);
+  # TODO: validate P & Q
+  return Math::Prime::Util::PP::is_frobenius_pseudoprime($n, $P, $Q);
+}
 sub is_frobenius_underwood_pseudoprime {
   my($n) = @_;
   return 0 if defined $n && int($n) < 0;
@@ -210,6 +215,12 @@ sub kronecker {
   return Math::Prime::Util::PP::kronecker(@_);
 }
 
+sub factorial {
+  my($n) = @_;
+  _validate_integer($n);
+  return Math::Prime::Util::PP::factorial($n);
+}
+
 sub binomial {
   my($n, $k) = @_;
   _validate_integer($n);
@@ -217,6 +228,14 @@ sub binomial {
   return Math::Prime::Util::PP::binomial($n, $k);
 }
 
+sub stirling {
+  my($n, $k, $type) = @_;
+  _validate_positive_integer($n);
+  _validate_positive_integer($k);
+  _validate_positive_integer($type) if defined $type;
+  return Math::Prime::Util::PP::stirling($n, $k, $type);
+}
+
 sub znorder {
   my($a, $n) = @_;
   _validate_positive_integer($a);
@@ -301,14 +320,6 @@ sub pminus1_factor {
   Math::Prime::Util::PP::pminus1_factor($n, $B1, $B2);
 }
 *pplus1_factor = \&pminus1_factor;
-sub ecm_factor {
-  my($n, $B1, $B2, $ncurves) = @_;
-  _validate_positive_integer($n);
-  _validate_positive_integer($B1) if defined $B1;
-  _validate_positive_integer($B2) if defined $B2;
-  _validate_positive_integer($ncurves) if defined $ncurves;
-  Math::Prime::Util::PP::ecm_factor($n, $B1, $B2, $ncurves);
-}
 
 sub divisors {
   my($n) = @_;
@@ -354,6 +365,21 @@ sub vecsum {
   _validate_integer($_) for @v;
   return Math::Prime::Util::PP::vecsum(@v);
 }
+sub vecprod {
+  my(@v) = @_;
+  _validate_integer($_) for @v;
+  return Math::Prime::Util::PP::vecprod(@v);
+}
+sub vecmin {
+  my(@v) = @_;
+  _validate_integer($_) for @v;
+  return Math::Prime::Util::PP::vecmin(@v);
+}
+sub vecmax {
+  my(@v) = @_;
+  _validate_integer($_) for @v;
+  return Math::Prime::Util::PP::vecmax(@v);
+}
 sub invmod {
   my ($a, $n) = @_;
   _validate_integer($a);
@@ -395,6 +421,12 @@ sub valuation {
   return Math::Prime::Util::PP::valuation($n, $k);
 }
 
+sub Pi {
+  my($digits) = @_;
+  _validate_positive_integer($digits) if defined $digits;
+  return Math::Prime::Util::PP::Pi($digits);
+}
+
 #############################################################################
 
 sub forprimes (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
@@ -469,6 +501,12 @@ sub fordivisors (&$) {    ## no critic qw(ProhibitSubroutinePrototypes)
 sub forpart (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
   Math::Prime::Util::PP::forpart(@_);
 }
+sub forcomb (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
+  Math::Prime::Util::PP::forcomb(@_);
+}
+sub forperm (&$;$) {    ## no critic qw(ProhibitSubroutinePrototypes)
+  Math::Prime::Util::PP::forperm(@_);
+}
 
 1;
 
